import tkinter as tk
from tkinter import ttk
from PIL import Image, ImageTk
import math
from math import ceil

# Function to reveal a part of the image when clicked
def reveal_blocks(start_x, start_y, end_x, end_y):
    for row in range(image_height // block_size):
        for col in range(image_width // block_size):
            block_left = col * block_size
            block_top = row * block_size
            block_right = (col + 1) * block_size
            block_bottom = (row + 1) * block_size

            # Check if the block is within the selection rectangle
            if (block_right >= start_x and block_left <= end_x) and (block_bottom >= start_y and block_top <= end_y):
                block = blocks[row][col]
                canvas.delete(block)
                img_part = ImageTk.PhotoImage(image.crop((col * block_size, row * block_size, (col + 1) * block_size, (row + 1) * block_size)))
                canvas.create_image(col * block_size, row * block_size, image=img_part, anchor=tk.NW)
                canvas.image_parts[(row, col)] = img_part  # Keep reference to avoid garbage collection

# Mouse event handlers for selecting area
def start_selection(event):
    global start_x, start_y
    start_x, start_y = event.x, event.y
    canvas.delete("selection_rect")  # Clear any previous selection rectangle

def update_selection(event):
    canvas.delete("selection_rect")  # Clear previous selection rectangle
    canvas.create_rectangle(start_x, start_y, event.x, event.y, outline='red', tag="selection_rect")

def end_selection(event):
    end_x, end_y = event.x, event.y
    reveal_blocks(start_x, start_y, end_x, end_y)
    canvas.delete("selection_rect")  # Clear the rectangle after revealing the blocks
    
def get_combobox_value():
    selected_value = c.get()
    print(f"Selected value: {selected_value}")
    
    #label.config(text=f"Selected: {selected_value}")

    encounter = ''
    record = False;
    
    with open("Dungeon Encounters.txt", "r") as file:
        lines = file.readlines()
        for line in lines:
            content = line.strip()
            
            if "Room " + str(selected_value) + ":" in content:
                record = True

            if "Room " + str(int(selected_value)+1) + ":" in content:
                record = False
                label.config(text=encounter)
                encounter = ''

            if record:
                a = content.replace(". ", ". \n")
                encounter+= a+'\n'
    
# Create main window
root = tk.Tk()
root.title("Image Reveal")

# Load the image
image_path = "206mapsmall.png"  # Replace with your image path
image = Image.open(image_path)
image_width, image_height = [740, 920]

# Set up canvas and image, and room options
options = list(range(1, 201))
c = ttk.Combobox(root)

c.pack()
c["values"] = options

button = tk.Button(root, text="Get Value", command=get_combobox_value)
button.pack()

label = tk.Label(root, text="Please select an option")
label.pack(side="left", anchor="nw")

label2 = tk.Label(root, text="Please select an option")
label2.pack(side="left", anchor = "w")


canvas = tk.Canvas(root, width=image_width, height=image_height)
canvas.pack(side="right", anchor = "ne")

# Set block size (you can adjust this)
block_size = 20

# Create black blocks to cover the image
canvas.image_parts = {}  # Dictionary to store image parts
blocks = []  # List to store block references for each row and column
for row in range(math.ceil(image_height // block_size)):
    row_blocks = []
    for col in range(math.ceil(image_width // block_size)):
        block = canvas.create_rectangle(col * block_size, row * block_size,
                                        (col + 1) * block_size, (row + 1) * block_size,
                                        fill="black", outline="gray")
        row_blocks.append(block)
    blocks.append(row_blocks)# Start the Tkinter event loop

canvas.bind("<ButtonPress-1>", start_selection)
canvas.bind("<B1-Motion>", update_selection)
canvas.bind("<ButtonRelease-1>", end_selection)    
root.mainloop()
